Struct conserve::archive::Archive

source ·
pub struct Archive { /* private fields */ }
An archive holding backup material.

Implementations

Make a new archive in a local directory.

Make a new archive in a new directory accessed by a Transport.

Open an existing archive.

Checks that the header is correct.

Returns a vector of band ids, in sorted order from first to last.

Return the BandId of the highest-numbered band, or Ok(None) if there are no bands, or an Err if any occurred reading the directory.

Return the last completely-written band id, if any.

Returns all blocks referenced by all bands.

Shows a progress bar as they’re collected.

Returns an iterator of blocks that are present and referenced by no index.

Delete bands, and the blocks that they reference.

If delete_band_ids is empty, this deletes no bands, but will delete any garbage blocks referenced by no existing bands.