Module conserve::backup

source ·
Make a backup by walking a source directory and copying the contents into an archive.

Structs

Configuration of how to make a backup.

Functions

Backup a source directory into a new band in the archive.