Struct conserve::index::IndexEntry

source ·
pub struct IndexEntry {
    pub apath: Apath,
    pub kind: Kind,
    pub mtime: i64,
    pub unix_mode: UnixMode,
    pub owner: Owner,
    pub mtime_nanos: u32,
    pub addrs: Vec<Address>,
    pub target: Option<String>,
}
Description of one archived file.

This struct is directly encoded/decoded to the json index file, and also can be constructed by stat-ing (but not reading) a live file.

Fields

apath: Apath

Path of this entry relative to the base of the backup, in apath form.

kind: Kind

Type of file.

mtime: i64

File modification time, in whole seconds past the Unix epoch.

unix_mode: UnixMode

Discretionary Access Control permissions (such as read/write/execute on unix)

owner: Owner

User and Group names of the owners of the file

mtime_nanos: u32

Fractional nanoseconds for modification time.

This is zero in indexes written prior to 0.6.2, but treating it as zero is harmless - around the transition files will be seen as potentially touched.

It seems moderately common that the nanos are zero, probably because the time was set by something that didn’t preserve them. In that case, skip serializing.

addrs: Vec<Address>

For stored files, the blocks holding the file contents.

target: Option<String>

For symlinks only, the target of the symlink.