pub struct IndexRead { /* private fields */ }Implementations
Sourceimpl IndexRead
impl IndexRead
Sourcepub fn iter_entries(self) -> IndexEntryIter<IndexHunkIter> ⓘ
pub fn iter_entries(self) -> IndexEntryIter<IndexHunkIter> ⓘ
Make an iterator that will return all entries in this band.
Sourcepub fn iter_hunks(&self) -> IndexHunkIter ⓘ
pub fn iter_hunks(&self) -> IndexHunkIter ⓘ
Make an iterator that returns hunks of entries from this index.