Module task

Module task 

Tasks are an abstraction to report progress on a long-running operation from the core library to a UI, such as a progress bar.

Structs

Task
A Task is constructed from a monitor. It can be updated while it’s alive. When it’s dropped, the progress bar is removed.
TaskList
TaskState