Struct conserve::BlockDir

source ·
pub struct BlockDir { /* private fields */ }
A readable, writable directory within a band holding data blocks.

Implementations

Create a BlockDir directory and return an object accessing it.

True if the named block is present in this directory.

Returns the compressed on-disk size of a block.

Read back the contents of a block, as a byte array.

To read a whole file, use StoredFile instead.

Return all the blocknames in the blockdir, in arbitrary order.

Return all the blocknames in the blockdir.

Check format invariants of the BlockDir.

Return a dict describing which blocks are present, and the length of their uncompressed data.

Return the entire contents of the block.

Checks that the hash is correct with the contents.