☰
Module backup
Structs
Functions
?
Module
conserve
::
backup
source
·
[
−
]
Make a backup by walking a source directory and copying the contents into an archive.
Structs
BackupOptions
Configuration of how to make a backup.
Functions
backup
Backup a source directory into a new band in the archive.